AbiConfigEntityBuilder class

Constructors

AbiConfigEntityBuilder()

Properties

baseDappUrl String?
getter/setter pair
cfg ↔ ListBuilder<AbiCfgEntity>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemIds SystemIdsEntityBuilder
getter/setter pair
vaultDappUrl String?
getter/setter pair

Methods

build() AbiConfigEntity
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(AbiConfigEntity other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(AbiConfigEntityBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited