AttributeEntity class abstract

This class represents an attribute entity, which contains properties related to an attribute.

Constructors

AttributeEntity([void updates(AttributeEntityBuilder)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
properties AttributePropertiesEntity
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AttributeEntityBuilder)) AttributeEntity
Rebuilds the instance.
inherited
toBuilder() AttributeEntityBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AttributeEntity>
no setter