CharacterEntity class abstract

This class represents a character entity with an address and name.

Constructors

CharacterEntity([void updates(CharacterEntityBuilder)])
factory

Properties

address String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CharacterEntityBuilder)) CharacterEntity
Rebuilds the instance.
inherited
toBuilder() CharacterEntityBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CharacterEntity>
no setter