ContractsEntity class abstract

This class represents the configuration for various contracts.

Constructors

ContractsEntity([void updates(ContractsEntityBuilder)])
factory

Properties

contractsVersion String
no setter
eveToken AddressConfigEntity
no setter
forwarder AddressConfigEntity
no setter
hashCode int
The hash code for this object.
no setterinherited
lensSeller AddressConfigEntity
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
world AddressConfigEntity
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ContractsEntityBuilder)) ContractsEntity
Rebuilds the instance.
inherited
toBuilder() ContractsEntityBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ContractsEntity>
no setter