SmartAssemblyEnum class
This class represents a smart assembly entity, which includes various properties
- Inheritance
-
- Object
- EnumClass
- SmartAssemblyEnum
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
SmartAssemblyEnum> -
no setter
-
values
→ BuiltSet<
SmartAssemblyEnum> -
no setter
Static Methods
-
valueOf(
String name) → SmartAssemblyEnum
Constants
- smartGate → const SmartAssemblyEnum
- smartStorageUnit → const SmartAssemblyEnum
- smartTurret → const SmartAssemblyEnum
- unknown → const SmartAssemblyEnum