GateLinkModuleEntity class abstract
This class represents a gate link module entity, which includes various properties
Constructors
- GateLinkModuleEntity([void updates(GateLinkModuleEntityBuilder)])
-
factory
Properties
- destinationGate → String
-
no setter
-
gatesInRange
→ BuiltList<
SimpleSmartAssemblyEntity> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLinked → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(GateLinkModuleEntityBuilder)) → GateLinkModuleEntity -
Rebuilds the instance.
inherited
-
toBuilder(
) → GateLinkModuleEntityBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
GateLinkModuleEntity> -
no setter